@@ -12,38 +12,36 @@
 ##############################################################################
 """Caching tool implementation.
 
-$Id: CachingPolicyManager.py 110655 2010-04-08 15:38:57Z tseaver $
+$Id: CachingPolicyManager.py 123172 2011-10-28 08:23:53Z yuppie $
 """
 
-from AccessControl import ClassSecurityInfo
+from AccessControl.SecurityInfo import ClassSecurityInfo
+from App.class_init import InitializeClass
 from App.Common import rfc1123_date
+from App.special_dtml import DTMLFile
 from DateTime.DateTime import DateTime
-from Globals import DTMLFile
-from Globals import InitializeClass
-from Globals import PersistentMapping
 from OFS.Cache import Cache
 from OFS.Cache import CacheManager
 from OFS.Cache import getVerifiedManagerIds
 from OFS.Cache import ZCM_MANAGERS
 from OFS.interfaces import IObjectWillBeMovedEvent
 from OFS.SimpleItem import SimpleItem
+from Persistence import PersistentMapping
 from Products.PageTemplates.Expressions import getEngine
 from Products.PageTemplates.Expressions import SecureModuleImporter
-from zope.app.container.interfaces import IObjectMovedEvent
+from zope.container.interfaces import IObjectMovedEvent
 from zope.interface import implements
 
-from Expression import Expression
-from interfaces import ICachingPolicy
-from interfaces import ICachingPolicyManager
-from interfaces.CachingPolicyManager \
-        import CachingPolicyManager as z2ICachingPolicyManager
-from permissions import ManagePortal
-from permissions import View
-from utils import _dtmldir
-from utils import _setCacheHeaders
-from utils import _ViewEmulator
-from utils import getToolByName
-from utils import registerToolInterface
+from Products.CMFCore.Expression import Expression
+from Products.CMFCore.interfaces import ICachingPolicy
+from Products.CMFCore.interfaces import ICachingPolicyManager
+from Products.CMFCore.permissions import ManagePortal
+from Products.CMFCore.permissions import View
+from Products.CMFCore.utils import _dtmldir
+from Products.CMFCore.utils import _setCacheHeaders
+from Products.CMFCore.utils import _ViewEmulator
+from Products.CMFCore.utils import getToolByName
+from Products.CMFCore.utils import registerToolInterface
 
 # This is lame :(
 # This listing is used to decide whether to wrap an object inside a "fake view"
@@ -121,6 +119,8 @@ class CPMCache(Cache):
 
         return _setCacheHeaders(ob, extra_context={})
 
+InitializeClass(CPMCache)
+
 
 class CachingPolicy:
     """
@@ -460,7 +460,6 @@ class CachingPolicyManager( SimpleItem, CacheManager ):
     """
 
     implements(ICachingPolicyManager)
-    __implements__ = z2ICachingPolicyManager
 
     id = 'caching_policy_manager'
     meta_type = 'CMF Caching Policy Manager'
