@@ -12,13 +12,18 @@
 ##############################################################################
 """ Customizable objects that come from the filesystem (base class).
 
-$Id: FSObject.py 110577 2010-04-07 06:33:17Z jens $
+$Id: FSObject.py 115542 2010-08-08 10:36:11Z hannosch $
 """
 
 import os
 
 from AccessControl.Permission import Permission
-from AccessControl.Role import RoleManager
+
+try:
+    from OFS.role import RoleManager
+except ImportError:
+    # BBB for Zope < 2.13
+    from AccessControl.Role import RoleManager
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from Acquisition import aq_base
 from Acquisition import aq_inner
