@@ -13,7 +13,7 @@
 ##############################################################################
 """ FSReSTMethod: Filesystem methodish Structured Text document.
 
-$Id: FSReSTMethod.py 110577 2010-04-07 06:33:17Z jens $
+$Id: FSReSTMethod.py 114572 2010-07-11 10:53:36Z hannosch $
 """
 
 from docutils.core import publish_parts
@@ -76,8 +76,7 @@ class FSReSTMethod(FSObject):
     output_encoding = 'utf8'
 
     manage_options=({'label' : 'Customize','action' : 'manage_main'},
-                    {'label' : 'View','action' : '',
-                     'help' : ('OFSP' ,'DTML-DocumentOrMethod_View.stx')},
+                    {'label' : 'View','action' : ''},
                    )
 
     security = ClassSecurityInfo()
