@@ -12,10 +12,11 @@
 ##############################################################################
 """ Unit test mixin classes and layers.
 
-$Id: testing.py 113209 2010-06-06 15:01:26Z hannosch $
+$Id: testing.py 114574 2010-07-11 11:20:20Z hannosch $
 """
 
 from OFS.SimpleItem import SimpleItem
+from Testing.ZopeTestCase import installPackage
 from Testing.ZopeTestCase.layer import ZopeLite
 from zope.component import adapts
 from zope.i18n.interfaces import IUserPreferredLanguages
@@ -96,6 +97,28 @@ class BrowserLanguages(object):
         return ('test',)
 
 
+class OFSZCMLLayer(ZopeLite):
+
+    @classmethod
+    def setUp(cls):
+        import zope.component
+        import OFS
+        import Products.Five
+        zcml.load_config('meta.zcml', zope.component)
+        try:
+            zcml.load_config('meta.zcml', OFS)
+            zcml.load_config('configure.zcml', OFS)
+        except IOError:  # Zope <= 2.13.0a2
+            zcml.load_config('meta.zcml', Products.Five)
+        # In Zope 2.12 this does an implicit commit
+        installPackage('OFS')
+        setHooks()
+
+    @classmethod
+    def tearDown(cls):
+        cleanUp()
+
+
 class EventZCMLLayer(ZopeLite):
 
     @classmethod
