@@ -12,7 +12,7 @@
 ##############################################################################
 """ Unit tests for PortalFolder module.
 
-$Id: test_PortalFolder.py 110655 2010-04-08 15:38:57Z tseaver $
+$Id: test_PortalFolder.py 115237 2010-07-30 14:55:08Z jens $
 """
 
 import unittest
@@ -29,8 +29,9 @@ from OFS.Image import manage_addFile
 from zope.component import getSiteManager
 from zope.component.interfaces import IFactory
 from zope.interface import implements
+from zope.interface.verify import verifyClass
 
-from Products.CMFCore.CatalogTool import CatalogTool
+from Products.CMFCore.interfaces import ICatalogTool
 from Products.CMFCore.exceptions import BadRequest
 from Products.CMFCore.interfaces import ITypesTool
 from Products.CMFCore.testing import ConformsToFolder
@@ -42,18 +43,45 @@ from Products.CMFCore.tests.base.dummy import DummySite
 from Products.CMFCore.tests.base.dummy import DummyUserFolder
 from Products.CMFCore.tests.base.testcase import SecurityRequestTest
 from Products.CMFCore.tests.base.testcase import SecurityTest
-from Products.CMFCore.tests.base.tidata import FTIDATA_CMF15
+from Products.CMFCore.tests.base.tidata import FTIDATA_CMF
 from Products.CMFCore.tests.base.tidata import FTIDATA_DUMMY
-from Products.CMFCore.tests.base.utils import has_path
 from Products.CMFCore.TypesTool import FactoryTypeInformation as FTI
 from Products.CMFCore.TypesTool import TypesTool
 from Products.CMFCore.WorkflowTool import WorkflowTool
-
+from types import TupleType
 
 def extra_meta_types():
     return [{'name': 'Dummy', 'action': 'manage_addFolder',
              'permission': 'View'}]
 
+class DummyCatalogTool:
+    implements(ICatalogTool)
+
+    def __init__(self):
+       self.paths = []
+       self.ids = []
+
+    def indexObject(self, object):
+       self.paths.append( '/'.join(object.getPhysicalPath()) )
+       self.ids.append( object.getId() )
+
+    def unindexObject(self, object):
+       self.paths.remove( '/'.join(object.getPhysicalPath()) )
+       self.ids.append( object.getId() )
+
+    def reindexObject(self, object):
+       pass
+
+    def __len__(self):
+       return len(self.paths)
+
+def has_path(catalog, path):
+    if type(path) is TupleType:
+       path = '/'.join(path)
+    return path in catalog.paths
+
+def has_id(catalog, id):
+    return id in catalog.ids
 
 class PortalFolderFactoryTests(SecurityTest):
 
@@ -130,14 +158,7 @@ class PortalFolderTests(ConformsToFolder, SecurityTest):
         SecurityTest.setUp(self)
         self.site = DummySite('site').__of__(self.root)
 
-    def test_z2interfaces(self):
-        from Interface.Verify import verifyClass
-        from OFS.IOrderSupport import IOrderedContainer
-
-        verifyClass(IOrderedContainer, self._getTargetClass())
-
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from OFS.interfaces import IOrderedContainer
 
         verifyClass(IOrderedContainer, self._getTargetClass())
@@ -217,7 +238,7 @@ class PortalFolderTests(ConformsToFolder, SecurityTest):
         #
         test = self._makeOne('test')
         ttool = self.site._setObject( 'portal_types', TypesTool() )
-        ctool = self.site._setObject( 'portal_catalog', CatalogTool() )
+        ctool = self.site._setObject( 'portal_catalog', DummyCatalogTool() )
         self.assertEqual( len(ctool), 0 )
 
         test._setObject( 'foo', DummyContent( 'foo' , catalog=1 ) )
@@ -238,7 +259,7 @@ class PortalFolderTests(ConformsToFolder, SecurityTest):
         # instantiation (Tracker issue 309)
         #
         ttool = self.site._setObject( 'portal_types', TypesTool() )
-        ctool = self.site._setObject( 'portal_catalog', CatalogTool() )
+        ctool = self.site._setObject( 'portal_catalog', DummyCatalogTool() )
         wftool = self.site._setObject( 'portal_workflow', WorkflowTool() )
         test = self._makeOne('test')
         wftool.notifyCreated(test)
@@ -254,7 +275,7 @@ class PortalFolderTests(ConformsToFolder, SecurityTest):
 
         test = self._makeOne('test')
         ttool = self.site._setObject( 'portal_types', TypesTool() )
-        ctool = self.site._setObject( 'portal_catalog', CatalogTool() )
+        ctool = self.site._setObject( 'portal_catalog', DummyCatalogTool() )
         self.assertEqual( len(ctool), 0 )
 
         test._setObject( 'sub', PortalFolder( 'sub', '' ) )
@@ -354,6 +375,45 @@ class PortalFolderTests(ConformsToFolder, SecurityTest):
         # Now copy/paste should raise a ValueError
         cookie = sub1.manage_copyObjects( ids = ( 'dummy', ) )
         self.assertRaises( ValueError, sub2.manage_pasteObjects, cookie )
+        
+    def test_contentPasteFollowsWorkflowGuards(self):
+       #
+       # Copy/Paste should obey workflow guards
+       #
+       ttool = self.site._setObject( 'portal_types', TypesTool() )
+       fti = FTIDATA_DUMMY[0].copy()
+       ttool._setObject( 'Dummy Content', FTI(**fti) )
+       ttool._setObject( 'Folder', FTI(**fti) )
+       folder = self._makeOne('folder', 'Folder')
+       content = self._makeOne('content')
+       folder._setObject('content', content)
+
+       # Allow adding of Dummy Content
+       ttool.Folder.manage_changeProperties(filter_content_types=False)
+
+       # Copy/paste verification should work fine
+       folder._verifyObjectPaste( content )
+
+       # Add a workflow with a blocking guard
+       # Based on TypesTools tests
+       class DummyWorkflow:
+           
+           _allow = False
+
+           def allowCreate(self, container, type_id):
+               return self._allow
+       
+       class DummyWorkflowTool:
+
+           def __init__(self):
+               self._workflows = [DummyWorkflow()]
+
+           def getWorkflowsFor(self, type_id):
+               return self._workflows
+      
+       # Now copy/paste verification should raise a ValueError
+       self.site.portal_workflow = DummyWorkflowTool()
+       self.assertRaises( ValueError, folder._verifyObjectPaste, content )
 
     def test_setObjectRaisesBadRequest(self):
         #
@@ -383,7 +443,7 @@ class PortalFolderTests(ConformsToFolder, SecurityTest):
         test = self._makeOne('test')
         test._setPortalTypeName('Dummy Content 15')
         ttool = self.site._setObject('portal_types', TypesTool())
-        ttool._setObject('Dummy Content 15', FTI(**FTIDATA_CMF15[0]))
+        ttool._setObject('Dummy Content 15', FTI(**FTIDATA_CMF[0]))
         acl_users = self.site._setObject('acl_users', DummyUserFolder())
         test._checkId('view.html')
         newSecurityManager(None, acl_users.user_foo)
@@ -442,29 +502,28 @@ class PortalFolderMoveTests(SecurityTest):
         from Products.CMFCore.PortalFolder import PortalFolder
 
         ttool = self.site._setObject( 'portal_types', TypesTool() )
-        ctool = self.site._setObject( 'portal_catalog', CatalogTool() )
-        ctool.addIndex('getId', 'FieldIndex')
+        ctool = self.site._setObject( 'portal_catalog', DummyCatalogTool() )
         self.assertEqual( len(ctool), 0 )
 
         folder = self._makeOne('folder')
         folder._setObject( 'sub', PortalFolder( 'sub', '' ) )
         folder.sub._setObject( 'foo', DummyContent( 'foo', catalog=1 ) )
         self.assertEqual( len(ctool), 1 )
-        self.failUnless( 'foo' in ctool.uniqueValuesFor('getId') )
-        self.failUnless( has_path(ctool._catalog,
+        self.failUnless( has_id(ctool, 'foo') )
+        self.failUnless( has_path(ctool,
                                   '/bar/site/folder/sub/foo') )
 
         transaction.savepoint(optimistic=True)
         folder.manage_renameObject(id='sub', new_id='new_sub')
         self.assertEqual( len(ctool), 1 )
-        self.failUnless( 'foo' in ctool.uniqueValuesFor('getId') )
-        self.failUnless( has_path(ctool._catalog,
+        self.failUnless( has_id(ctool, 'foo') )
+        self.failUnless( has_path(ctool,
                                   '/bar/site/folder/new_sub/foo') )
 
         folder._setObject( 'bar', DummyContent( 'bar', catalog=1 ) )
         self.assertEqual( len(ctool), 2 )
-        self.failUnless( 'bar' in ctool.uniqueValuesFor('getId') )
-        self.failUnless( has_path(ctool._catalog, '/bar/site/folder/bar') )
+        self.failUnless( has_id(ctool, 'bar') )
+        self.failUnless( has_path(ctool, '/bar/site/folder/bar') )
 
         folder._setObject( 'sub2', PortalFolder( 'sub2', '' ) )
         sub2 = folder.sub2
@@ -477,17 +536,17 @@ class PortalFolderMoveTests(SecurityTest):
         cookie = folder.manage_cutObjects(ids=['bar'])
         sub2.manage_pasteObjects(cookie)
 
-        self.failUnless( 'foo' in ctool.uniqueValuesFor('getId') )
-        self.failUnless( 'bar' in ctool.uniqueValuesFor('getId') )
+        self.failUnless( has_id( ctool, 'foo' ) )
+        self.failUnless( has_id( ctool, 'bar' ) )
         self.assertEqual( len(ctool), 2 )
-        self.failUnless( has_path(ctool._catalog,
+        self.failUnless( has_path(ctool,
                                   '/bar/site/folder/sub2/bar') )
 
     def test_contentPaste(self):
         #
         #   Does copy / paste work?
         #
-        ctool = self.site._setObject( 'portal_catalog', CatalogTool() )
+        ctool = self.site._setObject( 'portal_catalog', DummyCatalogTool() )
         ttool = self.site._setObject( 'portal_types', TypesTool() )
         fti = FTIDATA_DUMMY[0].copy()
         ttool._setObject( 'Dummy Content', FTI(**fti) )
@@ -503,9 +562,9 @@ class PortalFolderMoveTests(SecurityTest):
         self.failIf( 'dummy' in sub2.contentIds() )
         self.failIf( 'dummy' in sub3.objectIds() )
         self.failIf( 'dummy' in sub3.contentIds() )
-        self.failUnless( has_path(ctool._catalog, '/bar/site/sub1/dummy') )
-        self.failIf( has_path(ctool._catalog, '/bar/site/sub2/dummy') )
-        self.failIf( has_path(ctool._catalog, '/bar/site/sub3/dummy') )
+        self.failUnless( has_path(ctool, '/bar/site/sub1/dummy') )
+        self.failIf( has_path(ctool, '/bar/site/sub2/dummy') )
+        self.failIf( has_path(ctool, '/bar/site/sub3/dummy') )
 
         cookie = sub1.manage_copyObjects( ids = ( 'dummy', ) )
         # Waaa! force sub2 to allow paste of Dummy object.
@@ -519,9 +578,9 @@ class PortalFolderMoveTests(SecurityTest):
         self.failUnless( 'dummy' in sub2.contentIds() )
         self.failIf( 'dummy' in sub3.objectIds() )
         self.failIf( 'dummy' in sub3.contentIds() )
-        self.failUnless( has_path(ctool._catalog, '/bar/site/sub1/dummy') )
-        self.failUnless( has_path(ctool._catalog, '/bar/site/sub2/dummy') )
-        self.failIf( has_path(ctool._catalog, '/bar/site/sub3/dummy') )
+        self.failUnless( has_path(ctool, '/bar/site/sub1/dummy') )
+        self.failUnless( has_path(ctool, '/bar/site/sub2/dummy') )
+        self.failIf( has_path(ctool, '/bar/site/sub3/dummy') )
 
         transaction.savepoint(optimistic=True)
         cookie = sub1.manage_cutObjects( ids = ('dummy',) )
@@ -536,9 +595,9 @@ class PortalFolderMoveTests(SecurityTest):
         self.failUnless( 'dummy' in sub2.contentIds() )
         self.failUnless( 'dummy' in sub3.objectIds() )
         self.failUnless( 'dummy' in sub3.contentIds() )
-        self.failIf( has_path(ctool._catalog, '/bar/site/sub1/dummy') )
-        self.failUnless( has_path(ctool._catalog, '/bar/site/sub2/dummy') )
-        self.failUnless( has_path(ctool._catalog, '/bar/site/sub3/dummy') )
+        self.failIf( has_path(ctool, '/bar/site/sub1/dummy') )
+        self.failUnless( has_path(ctool, '/bar/site/sub2/dummy') )
+        self.failUnless( has_path(ctool, '/bar/site/sub3/dummy') )
 
 
 class ContentFilterTests(unittest.TestCase):
@@ -699,112 +758,130 @@ class ContentFilterTests(unittest.TestCase):
 
         from Products.CMFCore.PortalFolder import ContentFilter
 
-        cfilter = ContentFilter( created=DateTime( '2001/01/01' )
+        creation_date = DateTime('2001/01/01')
+        tz = creation_date.timezone()
+        cfilter = ContentFilter( created=creation_date
                                , created_usage='range:min' )
         dummy = self.dummy
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2000/12/31' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2001/12/31' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         dummy.created_date = DateTime( '2001/01/01' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         desc = str( cfilter )
         lines = desc.split('; ')
-        assert len( lines ) == 1
-        assert lines[0] == 'Created since: 2001/01/01'
+        self.assertEquals(len(lines), 1)
+        self.assertEquals( lines[0]
+                         , 'Created since: 2001/01/01 00:00:00 %s' % tz
+                         )
 
     def test_created2( self ):
 
         from Products.CMFCore.PortalFolder import ContentFilter
 
-        cfilter = ContentFilter( created=DateTime( '2001/01/01' )
+        creation_date = DateTime('2001/01/01')
+        tz = creation_date.timezone()
+        cfilter = ContentFilter( created=creation_date
                                , created_usage='range:max' )
 
         dummy = self.dummy
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2000/12/31' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         dummy.created_date = DateTime( '2001/12/31' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2001/01/01' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         desc = str( cfilter )
         lines = desc.split('; ')
-        assert len( lines ) == 1
-        assert lines[0] == 'Created before: 2001/01/01'
+        self.assertEquals(len(lines), 1)
+        self.assertEquals( lines[0]
+                         , 'Created before: 2001/01/01 00:00:00 %s' % tz
+                         )
 
     def test_modified( self ):
 
         from Products.CMFCore.PortalFolder import ContentFilter
 
+        creation_date = DateTime('2001/01/01')
+        tz = creation_date.timezone()
         cfilter = ContentFilter( modified=DateTime( '2001/01/01' )
                                , modified_usage='range:min' )
         dummy = self.dummy
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.modified_date = DateTime( '2000/12/31' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.modified_date = DateTime( '2001/12/31' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         dummy.modified_date = DateTime( '2001/01/01' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         desc = str( cfilter )
         lines = desc.split('; ')
-        assert len( lines ) == 1
-        assert lines[0] == 'Modified since: 2001/01/01'
+        self.assertEquals(len(lines), 1)
+        self.assertEquals( lines[0]
+                         , 'Modified since: 2001/01/01 00:00:00 %s' % tz
+                         )
 
     def test_modified2( self ):
 
         from Products.CMFCore.PortalFolder import ContentFilter
 
+        creation_date = DateTime('2001/01/01')
+        tz = creation_date.timezone()
         cfilter = ContentFilter( modified=DateTime( '2001/01/01' )
                                , modified_usage='range:max' )
         dummy = self.dummy
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.modified_date = DateTime( '2000/12/31' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         dummy.modified_date = DateTime( '2001/12/31' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.modified_date = DateTime( '2001/01/01' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         desc = str( cfilter )
         lines = desc.split('; ')
-        assert len( lines ) == 1
-        assert lines[0] == 'Modified before: 2001/01/01'
+        self.assertEquals(len(lines), 1)
+        self.assertEquals( lines[0]
+                         , 'Modified before: 2001/01/01 00:00:00 %s' % tz
+                         )
 
     def test_mixed( self ):
 
         from Products.CMFCore.PortalFolder import ContentFilter
 
+        creation_date = DateTime('2001/01/01')
+        tz = creation_date.timezone()
         cfilter = ContentFilter( created=DateTime( '2001/01/01' )
                                , created_usage='range:max'
                                , Title='foo'
                                )
 
         dummy = self.dummy
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2000/12/31' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2001/12/31' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2001/01/01' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
 
         dummy.title = 'ohsofoolish'
         del dummy.created_date
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2000/12/31' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
         dummy.created_date = DateTime( '2001/12/31' )
-        assert not cfilter( dummy )
+        self.failIf(cfilter(dummy))
         dummy.created_date = DateTime( '2001/01/01' )
-        assert cfilter( dummy )
+        self.failUnless(cfilter(dummy))
 
         desc = str( cfilter )
         lines = desc.split('; ')
-        assert len( lines ) == 2, lines
-        assert 'Created before: 2001/01/01' in lines
-        assert 'Title: foo' in lines
+        self.assertEquals(len(lines), 2)
+        self.failUnless('Created before: 2001/01/01 00:00:00 %s' % tz in lines)
+        self.failUnless('Title: foo' in lines)
 
 
 #------------------------------------------------------------------------------
